grab.base: API базового класса — Grab 0.6.30 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Grab 0.6.30 documentation »

# grab.base: API базового класса

`grab.base.` `BaseGrab`

  alias of `Grab`

#### Previous topic

Система кэширования сетевых запросов

#### Next topic

grab.error: классы исключений

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- modules |
- next |
- previous |
- Grab 0.6.30 documentation »

© Copyright 2011, Grigoriy Petukhov. Created using Sphinx 1.2.3.